/**
* A point representing a location in (x, y) coordinate space.
**/
export interface IGcPoint {
    x: number;
    y: number;
}
/**
 * Data structure with top-left coordinates (x, y) and width-height (w, h) of the rectangle.
 **/
export interface IGcRect extends IGcPoint {
    w: number;
    h: number;
}
/**
 * Data structure for text rectangle.
 */
export interface IGcTextRect extends IGcRect {
    angle: number;
    str: string;
    /**
     * Non-scaled character positions, starting from 0.
     * Length of the strPos array must be str.length + 1 (means the end position of the string).
     * */
    strPos: number[];
    /**
     * font height (without descent and ascent parts)
     * */
    fontHeight: number;
    /**
     * descent value, always negative value.
     * */
    fontDescent: number;
    scale: any;
    style: any;
    font: string;
    vertical: boolean;
    monospace: boolean;
    /**
     * The transformation matrix which was used to calculate the x and y values.
     **/
    transform: number[];
    dir: 'ltr' | 'rtl';
    /**
     * Associated marked content id.
     **/
    markedId?: string;
}
/**
 * A point representing a position in page coordinate space (x, y),
 * contains information about the index of the target page (pageIndex).
 **/
export declare class GcSelectionPoint implements IGcPoint {
    constructor(x: number, y: number, pageIndex: number);
    x: number;
    y: number;
    pageIndex: number;
}
