/**
* Describes what changes and functionality are allowed within the PDF.
**/
export type DocumentSecuritySummary = {
    /**
     * Indicates whether the document has been secured.
     **/
    hasSecurity: boolean;
    /**
     * Security method.
     **/
    securityMethod: string;
    /**
     * Encryption level
     **/
    encryptionLevel: string;
    /**
     * Indicates whether the document has document open password.
     **/
    documentOpenPassword: boolean;
    /**
     * Indicates whether the document has permission password.
     **/
    permissionsPassword: boolean;
    /**
     * Internal PDF permission flags.
     **/
    permissionFlags: number[] | null;
    /**
    * Allows document printing.
    **/
    printing: boolean;
    /**
     * Document assembly means that you can add/insert pages to your document.
     **/
    documentAssembly: boolean;
    /**
     * Allow users to copy the contents.
     **/
    contentCopying: boolean;
    /**
     * Allows screen reader software to utilize the text within the PDF file for reading the PDF file.
     **/
    contentCopyingForAccessibility: boolean;
    /**
     * Allows Page Extraction.
     **/
    pageExtraction: boolean;
    /**
     * Allows commenting.
     **/
    commenting: boolean;
    /**
     * Allows form filling.
     **/
    fillingOfFormFields: boolean;
    /**
     * Allows document signing.
     **/
    signing: boolean;
    /**
     * Deprecated. PDF page templates is the feature for creating dynamic forms.
     **/
    creationOfTemplatePages: boolean;
    /**
     * Indicates whether it is allowed to modify the contents of the document.
     **/
    modifyContents: boolean;
    /**
     * @ignore exclude from docs
     **/
    error?: string;
};
