import GcPdfViewer from "../GcPdfViewer";
import { XfaForm } from "./XfaForm";
import { XfaNode } from "./XfaNode";
/**
 * XFA layer API host. Used by Javascript actions.
 **/
export declare class XfaApiImpl {
    viewer: GcPdfViewer;
    private _form;
    constructor(viewer: GcPdfViewer);
    /**
     * Used by Javascript actions.
     * @ignore exclude from docs.
     **/
    get host(): XfaApiImpl;
    /**
    * Used by Javascript actions.
    * @ignore exclude from docs.
    **/
    get form(): XfaForm;
    /**
    * soPrintFunctions. Used by Javascript actions.
    * @ignore exclude from docs.
    **/
    get soPrintFunctions(): any;
    resolveNode(nodeName: string): XfaNode;
    /**
         * The Alert Box is by far the most used dialog because
         * it performs the most common operations. It displays short text messages (errors, warnings, etc.) and asks yes/no questions.
         * Used by Javascript actions.
         * @ignore exclude from docs
         * @param cMsg Required cMsg is the text displayed in the body of the Popup Window, and this is the only required argument.
         * @param nIcon Optional. The nIcon argument is the icon displayed to the left of the text.
         * Possible values areL 0 (default) - Error Message, 1 - Warning Message, 2 - Question, 3 - Information Message, 4 - No Icon displayed
         * @param nType Optional.  nType is the button combination.
         * Possible values: 0(default) - Single value Ok Button, 1 - 2 value Ok/Cancel Combination,
         * 2 - 2 value Yes/No Combination, 3 - 3 value Yes/No/Cancel Combination
         * @param cTitle Optional. cTitle is the window caption.
         * @param oDoc Optional. Not used. The oDoc argument forces the Alert Box to run in the context of a different PDF document. This option is used for multiple document applications.
         * @param oCheckbox Optional. Not used. The oCheckbox argument adds a checkbox to the bottom of the Alert Box. Its usage is more complicated than the other options. In order for it to return a value it requires a generic object literal as input. This object contains 3 properties, the checkbox text (cMsg), an initial value (bInitialValue), and the output value (bAfterValue). The output value is the only required property. The others are optional and have default values.
         */
    alert(cMsg: string | any, nIcon?: number, nType?: number, cTitle?: string, oDoc?: any, oCheckbox?: any): number;
    /**
     * Alias for alert method.  Used by Javascript actions.
     * @param cMsg
     * @param nIcon
     * @param nType
     * @param cTitle
     * @param oDoc
     * @param oCheckbox
     */
    messageBox(cMsg: string | any, nIcon?: number, nType?: number, cTitle?: string, oDoc?: any, oCheckbox?: any): number;
    /**
    * Opens the browser's print document dialog box.
    * @example
    * ```javascript
    * viewer.print();
    * ```
    * */
    print(): void;
    /**
     * Used by XFA scripting api: xfa.host.resetData()
     * @ignore exclude from docs
     **/
    resetData(): void;
    setFocus(xfaNode: XfaNode): void;
    /**
     * Causes the system to play a sound.
     * Used by Scripting API.
     * @ignore exclude from docs
     * @param param Optional. The system code for the appropriate sound. Each system code corresponds to a specific Windows program event.
     * 0 (Error) - Corresponds to the Critical Stop program event.
     * 1 (Warning) - Corresponds to the Exclamation program event.
     * 2 (Question) - Corresponds to the Question program event.
     * 3 (Status) - Corresponds to the Asterisk program event.
     * 4 (Default) - Corresponds to the Default Beep program event.
     **/
    beep(param: number): void;
    /**
     * Used by Scripting API: app.execMenuItem("SaveAs");
     * @ignore exclude from docs
     **/
    execMenuItem(menuItem: string): Promise<any>;
}
