/**
 * Data storage for the active document.
 **/
export declare class DataStorage {
    owner: any;
    private _data;
    private _images;
    /**
     * Constructor.
     * @param owner GcPdfViewer
     * @ignore
     **/
    constructor(owner: any);
    /**
     * Forces an immediate garbage collection.
     * This method supports the product infrastructure and is
     * not intended to be used directly from your code.
     * @ignore
     **/
    collectGarbage(): void;
    setImageDataFromUrl(imageFileName: string, cacheKey: string, resourceUrl: string): Promise<boolean>;
    /**
     * Creates an image element from an item created using the given key name.
     * @param keyName
     */
    createImage(imageFileName: string, cacheKey: string): HTMLImageElement | null;
    setImageSrc(img: HTMLImageElement, imageFileName: string): boolean;
    /**
     * The dispose method cleans up all stored data.
     **/
    dispose(): void;
    /**
     * Releases all objects that have been created for the active document.
     * This method is called automatically when the active document is closed.
     **/
    releaseResources(): void;
    /**
     * When passed a key name and value, will add that key to the given Storage object,
     * or update that key's value if it already exists.
     * @param keyName
     * @param keyValue
     */
    setItem(keyName: string, keyValue: Uint8Array | any): void;
    /**
     * When passed a key name, will return that key's value, or null if the key does not exist.
     * @param keyName
     */
    getItem(keyName: string | undefined): Uint8Array | any | null;
    getItemLength(keyName: string | undefined): number;
    hasItem(keyName: string | undefined): boolean;
    /**
     * Removes key from the given Storage object if it exists.
     * @param keyName
     */
    removeItem(keyName: string | undefined): void;
    releaseImage(keyName: string): void;
    /**
     * When passed a key name, will return base64-encoded key's value, or null if the key does not exist
     * @param keyName
     */
    getEncodedItem(keyName: string): string | null;
    /**
     * Auto-generate image file name.
     * @param fileName
     * @param extension
     */
    ensureNewImageFileName(fileName: string, extension?: string): string;
}
