/**
* PDF metadata provides additional information about a PDF document, including file name,
* title, date of creation, author, title, etc.
**/
export type DocumentInformation = {
    /**
     * Author name.
     **/
    Author?: string;
    /**
     * File name.
     **/
    FileName: string;
    /**
     * File size in bytes.
     **/
    FileSizeBytes: number;
    /**
     * Creation date
     **/
    CreationDate?: string;
    /**
    * Application that was used to create the file.
    **/
    Creator?: string;
    /**
     * Indicates whether the document contains an Acro Form.
     **/
    IsAcroFormPresent?: boolean;
    /**
     * @ignore exclude from docs.
     **/
    IsCollectionPresent?: boolean;
    /**
     * Indicates whether the document is linearized.
     **/
    IsLinearized?: boolean;
    /**
     * Determines whether the AcroForm contains XFA data.
     **/
    IsXFAPresent?: boolean;
    /**
     * Document keywords.
     **/
    Keywords: string;
    /**
     * Modification date.
     **/
    ModDate?: string;
    /**
     * PDF version.
     **/
    PDFFormatVersion?: string;
    /**
     * Producer name.
     **/
    Producer?: string;
    /**
     * Document subject.
     **/
    Subject?: string;
    /**
     * Document title.
     **/
    Title?: string;
    /**
     * PAges count.
     **/
    PagesCount?: number;
    /**
     * Page size (inches).
     **/
    PageSizeInches?: {
        width: number;
        height: number;
    };
};
